#! /bin/bash
# ----------------------------------------------------------------------------
# /var/install/config.d/php8-fpm - PHP_FPM configuration
#
# Creation   : 2018-11-19 schlotze
# Last update: $Id: php8-fpm.sh 67021 2019-08-07 12:59:32Z schlotze $
#
# Copyright (c) 2021 the eisfair team, <team(at)eisfair(dot)org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

pn=php8-fpm
an=apache2
retval=0

. /etc/default.d/${pn}
. /etc/config.d/${pn}
. /etc/config.d/${an}
. /var/install/include/eislib
if [ -f /etc/config.d/apache2_php8 ]
then
    . /etc/config.d/apache2_php8
fi

APACHE_USER=wwwrun:nogroup

packageName=${pn}

#---------------------------------------------------------------------------
# set parameter to no
#---------------------------------------------------------------------------
set_parameter_no ()
{
    # ${1} rewrite Parameter from 'yes' to 'no'

    CONFIG_FILE="/etc/config.d/${packageName}"

    # set parameter from 'yes' to 'no'
    sed "s/^${1}=.*/${1}='no'/" ${CONFIG_FILE} >/tmp/CONFIG_FILE_TMP
    mv /tmp/CONFIG_FILE_TMP ${CONFIG_FILE}
    chmod 0600 ${CONFIG_FILE}

    return
}

# ---------------------------------------------------------------------------
# deactivate module package
# ---------------------------------------------------------------------------
deactivate_modules () 
{
    rm -f /etc/apache2/mods-enabled/php8-fpm.conf
    rm -f /etc/apache2/mods-enabled/proxy_fcgi.load
    rm -f /etc/apache2/mods-enabled/proxy_http2.load
    rm -f /etc/php8/fpm/conf.d/eisfair.ini
    rm -f /etc/php8/fpm/conf.d/mysql.ini
    rm -f /etc/php8/fpm/conf.d/mysql-conf.ini
    rm -f /etc/php8/fpm/conf.d/mssql.ini
    rm -f /etc/php8/fpm/conf.d/interbase.ini
    rm -f /etc/php8/fpm/conf.d/pgsql.ini
    rm -f /etc/php8/fpm/conf.d/sqlite3.ini
    rm -f /etc/php8/fpm/conf.d/ldap.ini
    rm -f /etc/php8/fpm/conf.d/soap.ini
    rm -f /etc/php8/fpm/conf.d/apcu.ini
    rm -f /etc/php8/fpm/conf.d/redis.ini
    rm -f /etc/php8/fpm/conf.d/advantage.ini
    rm -f /etc/php8/fpm/conf.d/suhosin.ini
}

# ---------------------------------------------------------------------------
# create config
# ---------------------------------------------------------------------------
create_config()
{
    if ! ${_quiet:-false}
    then
        echo "Creating PHP8-FPM configuration ..."
    fi

    if [ "$PHP8FPM_INFO" = "yes" ]
    then
        if ! ${_quiet:-false}
        then
            echo
            echo "Writing info.php, gd.php and pdf.php to $APACHE2_DOCUMENT_ROOT"
            mecho --info "Set PHP8FPM_INFO to 'no' if you've tested functionallity..."
        fi
        echo '<?php phpinfo() ?>'>$APACHE2_DOCUMENT_ROOT/info.php

        echo '<?php
        
            if(!empty($_GET["text"])) {
                Header( "Content-type: image/png");
                // Header( "Content-type: image/jpeg");
        
                /* create image */
                $image = imagecreate(200,200);
        
                /* create color R=100, G=0, R=0 */
                $maroon = ImageColorAllocate($image,100,0,0);
        
                /*  create color R=255, G=255, R=255 */
                $white = ImageColorAllocate($image,255,255,255);
        
                /*  create color green */
                $green = ImageColorAllocate($image,0,255,0);
        
                /*  create color cyan */
                $cyan = ImageColorAllocate($image,132,193,255);
        
                /*  create white background*/
                ImageFilledRectangle($image,0,0,200,200,$white);
        
                /*  create frame */
                ImageRectangle($image,10,10,190,190,$maroon);
        
                /*  create a circle */
                imagearc($image, 100, 150, 150, 50, 0, 360, $green);
        
                /*  render image */
                ImagePNG($image);
                // ImageJPEG($image);
        
                /* cleanup memory */
                ImageDestroy($image);
        
            } else {
                function describeGDdyn(){
                    echo "<ul>";
                    echo "<li>GD support: ";
        
                    if(function_exists("gd_info")){
                        echo "<font color=\"#00ff00\">yes</font>";
                        $info = gd_info();
                        $keys  = array_keys($info);
        
                        for($i=1;$i<count($keys);$i++){
                            echo "</li>\n<li>".$keys[$i] .": " . yesNo($info[$keys[$i]]);
                        }
        
                    } else {
                        echo "<font color=\"#ff0000\">no</font>";
                    }
        
                    echo "</li></ul>";
                }
        
                function yesNo($bool){
                    if($bool){
                        return "<font color=\"#00ff00\"> yes</font>";
                    }else{
                        return "<font color=\"#ff0000\"> no</font>";
                    }
                }
        
                describeGDdyn();
        
                echo "<p>";
        
                echo "<form action=gd.php method=GET>";
                echo "<input type=text name=text value=eisfair> <input type=submit value=TestIt!>";
                echo "</form>";
            }
        
            ?>'>$APACHE2_DOCUMENT_ROOT/gd.php

        echo '<?php
        
            $RADIUS = 200.0;
            $MARGIN = 20.0;
        
            $p = PDF_new();
        
            PDF_open_file($p, "");
        
            PDF_set_info($p, "Creator", "pdfclock.php");
            PDF_set_info($p, "Author", "Rainer Schaaf");
            PDF_set_info($p, "Title", "PDF clock (PHP)");
        
            PDF_begin_page($p, 2 * ($RADIUS + $MARGIN), 2 * ($RADIUS + $MARGIN));
        
            PDF_translate($p, $RADIUS + $MARGIN, $RADIUS + $MARGIN);
            PDF_setcolor($p, "both", "rgb", 0.0, 0.0, 1.0, 0.0);
            PDF_save($p);
        
            # minute strokes
            PDF_setlinewidth($p, 2.0);
            for ($alpha = 0; $alpha < 360; $alpha += 6) {
                PDF_rotate($p, 6.0);
                PDF_moveto($p, $RADIUS, 0.0);
                PDF_lineto($p, $RADIUS-$MARGIN/3, 0.0);
                PDF_stroke($p);
            }
        
            PDF_restore($p);
            PDF_save($p);
        
            # 5 minute strokes
            PDF_setlinewidth($p, 3.0);
            for ($alpha = 0; $alpha < 360; $alpha += 30) {
                PDF_rotate($p, 30.0);
                PDF_moveto($p, $RADIUS, 0.0);
                PDF_lineto($p, $RADIUS-$MARGIN, 0.0);
                PDF_stroke($p);
            }
        
            $ltime = getdate();
        
            # draw hour hand
            PDF_save($p);
            PDF_rotate($p, -(($ltime['minutes']/60.0)+$ltime['hours']-3.0)*30.0);
            PDF_moveto($p, -$RADIUS/10, -$RADIUS/20);
            PDF_lineto($p, $RADIUS/2, 0.0);
            PDF_lineto($p, -$RADIUS/10, $RADIUS/20);
            PDF_closepath($p);
            PDF_fill($p);
            PDF_restore($p);
        
            # draw minute hand
            PDF_save($p);
            PDF_rotate($p, -(($ltime['seconds']/60.0)+$ltime['minutes']-15.0)*6.0);
            PDF_moveto($p, -$RADIUS/10, -$RADIUS/20);
            PDF_lineto($p, $RADIUS * 0.8, 0.0);
            PDF_lineto($p, -$RADIUS/10, $RADIUS/20);
            PDF_closepath($p);
            PDF_fill($p);
            PDF_restore($p);
        
            # draw second hand
            PDF_setcolor($p, "both", "rgb", 1.0, 0.0, 0.0, 0.0);
            PDF_setlinewidth($p, 2);
            PDF_save($p);
            PDF_rotate($p, -(($ltime['seconds'] - 15.0) * 6.0));
            PDF_moveto($p, -$RADIUS/5, 0.0);
            PDF_lineto($p, $RADIUS, 0.0);
            PDF_stroke($p);
            PDF_restore($p);
        
            # draw little circle at center
            PDF_circle($p, 0, 0, $RADIUS/30);
            PDF_fill($p);
        
            PDF_restore($p);
            PDF_end_page($p);
        
            PDF_close($p);
        
            $buf = PDF_get_buffer($p);
            $len = strlen($buf);
        
            header("Content-type: application/pdf");
            header("Content-Length: $len");
            header("Content-Disposition: inline; filename=pdfclock.pdf");
            print $buf;
        
            PDF_delete($p);
            ?>'>$APACHE2_DOCUMENT_ROOT/pdf.php

        chown $APACHE_USER $APACHE2_DOCUMENT_ROOT/info.php  $APACHE2_DOCUMENT_ROOT/pdf.php $APACHE2_DOCUMENT_ROOT/gd.php
    else
        rm -f $APACHE2_DOCUMENT_ROOT/info.php $APACHE2_DOCUMENT_ROOT/gd.php $APACHE2_DOCUMENT_ROOT/pdf.php
    fi

    # =============================================================================
    # Auswerten der Config Parameter
    # =============================================================================
    
    rm -f /etc/php8/fpm/conf.d/eisfair.ini
    # -----------------------------------------------------------------------------
    # Log Error
    # -----------------------------------------------------------------------------
    if [ "${PHP8FPM_LOG_ERROR}" = "yes" ] ; then
        {
            echo "; Log errors into a log file (server-specific log, stderr, or error_log (below))"
            echo "; As stated above, you\re strongly advised to use error logging in place of"
            echo "; error displaying on production web sites."
            echo "log_errors = On"
            echo 
        } >> /etc/php8/fpm/conf.d/eisfair.ini
    else
        {
            echo "; Log errors into a log file (server-specific log, stderr, or error_log (below))"
            echo "; As stated above, you\re strongly advised to use error logging in place of"
            echo "; error displaying on production web sites."
            echo "log_errors = Off"
            echo 
        } >> /etc/php8/fpm/conf.d/eisfair.ini
    fi
    # -----------------------------------------------------------------------------
    # Display Errors
    # -----------------------------------------------------------------------------
    if [ "${PHP8FPM_DISPLAY_ERRORS}" = "yes" ] ; then
        {
            echo "; Print out errors (as a part of the output).  For production web sites,"
            echo "; you\re strongly encouraged to turn this feature off, and use error logging"
            echo "; instead (see below).  Keeping display_errors enabled on a production web site"
            echo "; may reveal security information to end users, such as file paths on your Web"
            echo "; server, your database schema or other information."
            echo "display_errors = On"
            echo 
        } >> /etc/php8/fpm/conf.d/eisfair.ini
    else
        {
            echo "; Print out errors (as a part of the output).  For production web sites,"
            echo "; you\re strongly encouraged to turn this feature off, and use error logging"
            echo "; instead (see below).  Keeping display_errors enabled on a production web site"
            echo "; may reveal security information to end users, such as file paths on your Web"
            echo "; server, your database schema or other information."
            echo "display_errors = Off"
            echo 
        } >> /etc/php8/fpm/conf.d/eisfair.ini
    fi
    
    # -----------------------------------------------------------------------------
    # Extension Directory
    # -----------------------------------------------------------------------------
    {
        echo '; Directory in which the loadable extensions (modules) reside.'
        echo "extension_dir = /usr/lib/php8/extensions"
    } >> /etc/php8/fpm/conf.d/eisfair.ini
    
    # -----------------------------------------------------------------------------
    # SendMail Path
    # -----------------------------------------------------------------------------
    if [ -f "${PHP8FPM_SENDMAIL_PATH}" -a "${PHP8FPM_SENDMAIL_PATH}" != "" ]
    then
        {
            echo '; For Unix only.  You may supply arguments as well (default: "sendmail -t -i").'
            echo "sendmail_path = ${PHP8FPM_SENDMAIL_PATH} ${PHP8FPM_SENDMAIL_APP}"
            echo 
        } >> /etc/php8/fpm/conf.d/eisfair.ini
    else
        {
            echo '; For Unix only.  You may supply arguments as well (default: "sendmail -t -i").'
            echo "sendmail_path = /usr/sbin/sendmail -t -i"
            echo 
        } >> /etc/php8/fpm/conf.d/eisfair.ini
    fi
    
    # -----------------------------------------------------------------------------
    # Date Timezone Settings
    # -----------------------------------------------------------------------------
    {
        echo '[Date]'
        echo '; Defines the default timezone used by the date functions'
        echo "date.timezone = \"${PHP8FPM_DATE_TIMEZONE}\""
        echo
        echo ';date.default_latitude = 31.7667'
        echo ';date.default_longitude = 35.2333'
        echo
        echo ';date.sunrise_zenith = 90.583333'
        echo ';date.sunset_zenith = 90.583333'
    } >> /etc/php8/fpm/conf.d/eisfair.ini
    # -----------------------------------------------------------------------------
    # Include Path
    # -----------------------------------------------------------------------------
    {
        echo '; UNIX: "/path1:/path2"'
        echo 'include_path = ".:/usr/share/php8:/usr/include/php8"'
        echo 
    } >> /etc/php8/fpm/conf.d/eisfair.ini
    # -----------------------------------------------------------------------------
    # default charset
    # -----------------------------------------------------------------------------
    lang=`echo ${PHP8FPM_DEFAULT_CHARSET} | tr 'A-Z' 'a-z'`
    
    case ${lang} in
        *iso88591 ) # iso-8859-1
            PHP8FPM_DEFAULT_CHARSET='ISO-8859-1'
            ;;
        *euro ) # iso-8859-15, (-1 with Euro charachter etc.)
            PHP8FPM_DEFAULT_CHARSET='ISO-8859-15'
            ;;
        * ) # default to utf-8
            PHP8FPM_DEFAULT_CHARSET='UTF-8'
            ;;
        esac
    {
        echo "default_charset = ${PHP8FPM_DEFAULT_CHARSET}"
        echo 
    } >> /etc/php8/fpm/conf.d/eisfair.ini
    
    # -----------------------------------------------------------------------------
    # Upload directory
    # -----------------------------------------------------------------------------
    if [ -d ${PHP8FPM_UPLOAD_DIR} ] ; then
        {
            echo "; Temporary directory for HTTP uploaded files (will use system default if not"
            echo "; specified)."
            echo "upload_tmp_dir = ${PHP8FPM_UPLOAD_DIR}"
            echo 
        } >> /etc/php8/fpm/conf.d/eisfair.ini
    else
        {
            echo "; Temporary directory for HTTP uploaded files (will use system default if not"
            echo "; specified)."
            echo 'upload_tmp_dir = "/tmp"'
            echo 
        } >> /etc/php8/fpm/conf.d/eisfair.ini
    fi
    
    # -----------------------------------------------------------------------------
    # 
    # -----------------------------------------------------------------------------
    {
        echo "; Maximum allowed size for uploaded files."
        echo "upload_max_filesize = ${PHP8FPM_MAX_UPLOAD_FILESIZE}"
        echo
        echo "; Maximum execution time of each script, in seconds"
        echo "max_execution_time = ${PHP8FPM_MAX_EXECUTION_TIME}"
        echo
        echo "; Maximum amount of memory a script may consume (8MB)"
        echo "memory_limit = ${PHP8FPM_MEMORY_LIMIT}"
        echo 
        echo "; Maximum size of POST data that PHP will accept."
        echo "post_max_size = ${PHP8FPM_MAX_POST_SIZE}"
        echo 
        echo "; Turn of the pcre jit compiler"
        echo "pcre.jit = 0"
        echo
    } >> /etc/php8/fpm/conf.d/eisfair.ini
    # -----------------------------------------------------------------------------
    # load modules
    # -----------------------------------------------------------------------------
    {
        echo "extension = bz2.so"
        echo "extension = curl.so"
        echo "extension = gd.so"
        echo "extension = gettext.so"
        echo "extension = iconv.so"
        echo "extension = mcrypt.so"
        echo "extension = openssl.so"
        echo "extension = pdo.so"
        echo "extension = pdo_dblib.so"
        echo "extension = zlib.so"
        echo 
    } >> /etc/php8/fpm/conf.d/eisfair.ini
    # -----------------------------------------------------------------------------
    
    # -----------------------------------------------------------------------------
    # handling for php8 modules
    # -----------------------------------------------------------------------------
    for NAME in $(ls /etc/php8/conf.d/*.ini); do
    	if [ "$(basename ${NAME})" != "eisfair.ini" ]
    	then
            ln -sf /etc/php8/conf.d/$(basename ${NAME}) /etc/php8/fpm/conf.d/$(basename ${NAME})
        fi
    done

    # -----------------------------------------------------------------------------
    # MYSQL
    # -----------------------------------------------------------------------------
    if [ "${PHP8FPM_EXT_MYSQL}" = "yes" ] 
    then
        module_status=`eisman check php8-mysql`
        if [ ${module_status} != "installed" ]
        then
            set_parameter_no "PHP8FPM_EXT_MYSQL"
            mecho --error "You cannot activate MySQL-Extension. You need to install php8-mysql first."                
        else
            if [ -z "$PHP8FPM_EXT_MYSQL_SOCKET" ]
            then
                if [ -z "$PHP8FPM_EXT_MYSQL_HOST" ]
                then
                    if [ -e "/run/mysql/mysql.sock" ]
                    then
                        PHP8FPM_EXT_MYSQL_SOCKET="/run/mysql/mysql.sock"
                    elif [ -e "/var/lib/mysql/mysql.sock" ]
                    then
                        PHP8FPM_EXT_MYSQL_SOCKET="/var/lib/mysql/mysql.sock"
                    fi 
               fi
            fi
            if [ ! -e "$PHP8FPM_EXT_MYSQL_SOCKET" ]
            then
                mecho --error "The MySQL Socket you configured does not exist. Connecting to MySQL will not be possible."
            fi
            if [ -z "$PHP8FPM_EXT_MYSQL_HOST" ]
            then
                PHP8FPM_EXT_MYSQL_PORT=""
            else
                if [ -z "$PHP8FPM_EXT_MYSQL_PORT" ] 
                then
                    PHP8FPM_EXT_MYSQL_PORT="3306"
                fi
            fi
            ln -sf /etc/php8/conf.d/mysql.ini /etc/php8/fpm/conf.d/mysql.ini
    
            cat >/etc/php8/fpm/conf.d/mysql-conf.ini <<EOF
[mysql]
mysql.allow_local_infile=On
mysql.allow_persistent=On
mysql.cache_size=2000
mysql.max_persistent=-1
mysql.max_links=-1
mysql.default_port=${PHP8FPM_EXT_MYSQL_PORT}
mysql.default_socket=${PHP8FPM_EXT_MYSQL_SOCKET}
mysql.default_host=${PHP8FPM_EXT_MYSQL_HOST}
mysql.default_user=
mysql.default_password=
mysql.connect_timeout=60
mysql.trace_mode=Off
[pdo_mysql]
pdo_mysql.cache_size=2000
pdo_mysql.default_socket=${PHP8FPM_EXT_MYSQL_SOCKET}
[mysqli]
mysqli.max_persistent=-1
mysqli.allow_local_infile=On
mysqli.allow_persistent=On
mysqli.max_links=-1
mysqli.cache_size=2000
mysqli.default_port=${PHP8FPM_EXT_MYSQL_PORT}
mysqli.default_socket=${PHP8FPM_EXT_MYSQL_SOCKET}
mysqli.default_host=${PHP8FPM_EXT_MYSQL_HOST}
mysqli.default_user=
mysqli.default_pw=
mysqli.reconnect=Off
[mysqlnd]
mysqlnd.collect_statistics=On
mysqlnd.collect_memory_statistics=Off
;mysqlnd.net_cmd_buffer_size=2048
;mysqlnd.net_read_buffer_size=32768
EOF
        fi
    else
        rm -f /etc/php8/fpm/conf.d/mysql.ini
        rm -f /etc/php8/fpm/conf.d/mysql-conf.ini
    fi
    
    # -----------------------------------------------------------------------------
    # INTERBASE
    # -----------------------------------------------------------------------------
    if [ "${PHP8FPM_EXT_INTER}" = "yes" ] ; then
        module_status=`eisman check php8-firebird`
        if [ ${module_status} != "installed" ]
        then
            set_parameter_no "PHP8FPM_EXT_INTER"
            mecho --error "You cannot activate INTERBASE/FIREBIRD-Extension. You need to install php8-firebird first."                
        else
            ln -sf /etc/php8/conf.d/interbase.ini /etc/php8/fpm/conf.d/interbase.ini
    
        fi
    else
        rm -f /etc/php8/fpm/conf.d/interbase.ini
    fi
    
    # -----------------------------------------------------------------------------
    # MSSQL
    # -----------------------------------------------------------------------------
    if [ "${PHP8FPM_EXT_MSSQL}" = "yes" ] ; then
        cat >/etc/php8/fpm/conf.d/mssql.ini <<EOF
extension=pdo_dblib.so

EOF
    else
        rm -f /etc/php8/fpm/conf.d/mssql.ini
    fi
    
    # -----------------------------------------------------------------------------
    # POSTGRESQL
    # -----------------------------------------------------------------------------
    if [ "${PHP8FPM_EXT_PGSQL}" = "yes" ] ; then
        module_status=`eisman check php8-pgsql`
        if [ ${module_status} != "installed" ]
        then
            set_parameter_no "PHP8FPM_EXT_PGSQL"
            mecho --error "You cannot activate PGSQL-Extension. You need to install php8-pgsql first."                
        else
            ln -sf /etc/php8/conf.d/pgsql.ini /etc/php8/fpm/conf.d/pgsql.ini
        fi
    else
        rm -f /etc/php8/fpm/conf.d/pgsql.ini
    fi
    
    # -----------------------------------------------------------------------------
    # SQLite3
    # -----------------------------------------------------------------------------
    if [ "${PHP8FPM_EXT_SQLITE3}" = "yes" ] ; then
        module_status=`eisman check php8-sqlite`
        if [ ${module_status} != "installed" ]
        then
            set_parameter_no "PHP8FPM_EXT_SQLITE3"
            mecho --error "You cannot activate SQLITE-Extension. You need to install php8-sqlite first."                
        else
            ln -sf /etc/php8/conf.d/sqlite3.ini /etc/php8/fpm/conf.d/sqlite3.ini 
        fi
    else
        rm -f /etc/php8/fpm/conf.d/sqlite3.ini
    fi
    
    # -----------------------------------------------------------------------------
    # SOAP
    # -----------------------------------------------------------------------------
    if [ "${PHP8FPM_EXT_SOAP}" = "yes" ] ; then
        module_status=`eisman check php8-soap`
        if [ ${module_status} != "installed" ]
        then
            set_parameter_no "PHP8FPM_EXT_SOAP"
            mecho --error "You cannot activate SOAP-Extension. You need to install php8-soap first."                
        else
            ln -sf /etc/php8/conf.d/soap.ini /etc/php8/fpm/conf.d/soap.ini 
        fi
    else
        rm -f /etc/php8/fpm/conf.d/soap.ini
    fi
    
    # -----------------------------------------------------------------------------
    # LDAP
    # -----------------------------------------------------------------------------
    if [ "${PHP8FPM_EXT_LDAP}" = "yes" ] ; then
        module_status=`eisman check php8-ldap`
        if [ ${module_status} != "installed" ]
        then
            set_parameter_no "PHP8FPM_EXT_LDAP"
            mecho --error "You cannot activate LDAP-Extension. You need to install php8-ldap first."                
        else
            ln -sf /etc/php8/conf.d/ldap.ini /etc/php8/fpm/conf.d/ldap.ini
        fi
    else
        rm -f /etc/php8/fpm/conf.d/ldap.ini
    fi
    
    # -----------------------------------------------------------------------------
    # CACHE
    # -----------------------------------------------------------------------------
    if [ "${PHP8FPM_EXT_CACHE}" = "apcu" ]
    then
        module_status=`eisman check php8-apcu`
        if [ ${module_status} != "installed" ]
        then
            set_parameter_no "PHP8FPM_EXT_CACHE"
            mecho --error "You cannot activate APCU-Extension. You need to install php8-apcu first."                
        else
            ln -sf /etc/php8/conf.d/apcu.ini /etc/php8/fpm/conf.d/apcu.ini
        fi
        rm -f /etc/php8/fpm/conf.d/redis.ini
    elif [ "${PHP8FPM_EXT_CACHE}" = "redis" ]
    then
        module_status=`eisman check php8-redis`
        if [ ${module_status} != "installed" ]
        then
            set_parameter_no "PHP8FPM_EXT_CACHE"
            mecho --error "You cannot activate REDIS-Extension. You need to install php8-redis first."                
        else
            ln -sf /etc/php8/conf.d/redis.ini /etc/php8/fpm/conf.d/redis.ini
        fi
        rm -f /etc/php8/fpm/conf.d/apcu.ini
    elif [ "${PHP8FPM_EXT_CACHE}" = "apcu+redis" ]
    then
        module_status=`eisman check php8-apcu`
        if [ ${module_status} != "installed" ]
        then
            set_parameter_no "PHP8FPM_EXT_CACHE"
            mecho --error "You cannot activate APCU-Extension. You need to install php8-apcu first."                
        else
            ln -sf /etc/php8/conf.d/apcu.ini /etc/php8/fpm/conf.d/apcu.ini
        fi
        module_status=`eisman check php8-redis`
        if [ ${module_status} != "installed" ]
        then
            set_parameter_no "PHP8FPM_EXT_CACHE"
            mecho --error "You cannot activate REDIS-Extension. You need to install php8-redis first."                
        else
            ln -sf /etc/php8/conf.d/redis.ini /etc/php8/fpm/conf.d/redis.ini
        fi
    elif [ "${PHP8FPM_EXT_CACHE}" = "no" ]
    then
        rm -f /etc/php8/fpm/conf.d/apcu.ini
        rm -f /etc/php8/fpm/conf.d/redis.ini
    fi
    # =============================================================================
    
    chmod 600 /etc/config.d/php8-fpm
}

# ---------------------------------------------------------------------------
# create php8 start
# ---------------------------------------------------------------------------
create_php8_start()
{
    case ${START_PHP8_FPM} in
    yes)
        if [ -f /etc/config.d/apache2 ]
        then
            . /etc/config.d/apache2

            # check if correct worker in apache2 is used (must be mpm_event)
            if [ "$APACHE2_MPM" = "prefork" ]
            then
                START_PHP8_FPM="no"
                set_parameter_no "START_PHP8_FPM"
                mecho --error "You have apache2 configured to use mpm prefork,"
                mecho --error "but php8-fpm required mpm event or mpm worker."
                mecho --error "START_PHP8_FPM will be set to 'no'."
                exit 1
            fi
        fi

        php5_status=`eisman check apache2_php5`

        if [ ${php5_status} != "not-installed" ]
        then
            if [ -f /etc/config.d/apache2_php5 ]
            then
                . /etc/config.d/apache2_php5
            fi
            if [ "${START_PHP5}" != "no" ]
            then
                START_PHP8_FPM="no"
                set_parameter_no "START_PHP8_FPM"
                mecho --error "apache2_php5 is installed and enabled.            "
                mecho --error "You cannot use php5 and php8-fpm at the same time."
                mecho --error "Setting START_PHP8_FPM to 'no'.                   "
            fi
        fi

        php7_status=`eisman check apache2_php7`

        if [ ${php7_status} != "not-installed" ]
        then
            if [ -f /etc/config.d/apache2_php7 ]
            then
                . /etc/config.d/apache2_php7
            fi
            if [ "${START_PHP7}" != "no" ]
            then
                START_PHP8_FPM="no"
                set_parameter_no "START_PHP8_FPM"
                mecho --error "apache2_php7 is installed and enabled.            "
                mecho --error "You cannot use php7 and php8-fpm at the same time."
                mecho --error "Setting START_PHP8_FPM to 'no'.                   "
            fi
        fi

        php8_status=`eisman check apache2_php8`

        if [ ${php8_status} != "not-installed" ]
        then
            if [ -f /etc/config.d/apache2_php8 ]
            then
                . /etc/config.d/apache2_php8
            fi
            if [ "${START_PHP8}" != "no" ]
            then
                START_PHP8_FPM="no"
                set_parameter_no "START_PHP8_FPM"
                mecho --error "apache2_php8 is installed and enabled.            "
                mecho --error "You cannot use php8 and php8-fpm at the same time."
                mecho --error "Setting START_PHP8_FPM to 'no'.                   "
            fi
        fi

        php7fpm_status=`eisman check php7-fpm`

        if [ ${php7fpm_status} != "not-installed" ]
        then
            if [ -f /etc/config.d/php7-fpm ]
            then
                . /etc/config.d/php7-fpm
            fi
            if [ "${START_PHP7_FPM}" != "no" ]
            then
                START_PHP8_FPM="no"
                set_parameter_no "START_PHP8_FPM"
                mecho --error "php7-fpm is installed and enabled.                    "
                mecho --error "You cannot use php7-fpm and php8-fpm at the same time."
                mecho --error "Setting START_PHP8_FPM to 'no'.                       "
            fi
        fi
        ;;
    esac
}

# ---------------------------------------------------------------------------
# apache start
# ---------------------------------------------------------------------------
apache_start()
{
    # reload apache2 configuration if apache is running
    if [ -f /run/httpd.pid ] ||
       [ -f /run/apache2.pid ]
    then
        /usr/sbin/service stop apache2
        sleep 3
        /usr/sbin/service start apache2
    fi
} 

# ----------------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------------
rm -f /etc/php8/conf.d/eisfair.ini

create_php8_start

if [ "$START_PHP8_FPM" = "yes" ]
then
    create_config

    # if all checks are fine add php8-fpm.conf to apache2 mods-available
    cat > /etc/apache2/mods-available/php8-fpm.conf <<EOF
#==============================================================
# Do not edit this file, edit /etc/config.d/php8-fpm
# Creation date: $EISDATE $EISTIME

# Depends: proxy
<IfModule !proxy_http2_module>
    LoadModule proxy_http2_module /usr/lib/apache2/modules/mod_proxy_http2.so
</IfModule>

# Depends: fcgi
<IfModule !proxy_fcgi_module>
    LoadModule proxy_fcgi_module /usr/lib/apache2/modules/mod_proxy_fcgi.so
</IfModule>

ProxyFCGIBackendType GENERIC
#<FilesMatch \.php$>
#    <If "-f %{REQUEST_FILENAME}">
#        SetHandler "proxy:unix:/run/php8-fpm.sock|fcgi://localhost"
#    </If>
#</FilesMatch>
DirectoryIndex index.php
AddType application/x-httpd-php .php

EOF

    ln -sf /etc/apache2/mods-available/php8-fpm.conf /etc/apache2/mods-enabled/php8-fpm.conf

# create logrotate file 
cat > /etc/logrotate.d/php-fpm <<EOF
#---------------------------------------------------------------------
# /etc/logrotate.d/php8-fpm file generated by /var/install/config.d/php8-fpm.sh
#
# Do not edit this file, edit /etc/config.d/php8-fpm.sh
# Creation Date: $EISDATE $EISTIME
#---------------------------------------------------------------------
/var/www/log/php-fpm*log {
    weekly
    missingok
    rotate 7
    compress
    delaycompress
    notifempty
    create 640 root nogroup
    sharedscripts
    postrotate
        /usr/sbin/service --quiet restart php8-fpm.service
    endscript
}
EOF

fi

if [ "$START_PHP8_FPM" = "yes" ]
then
	 # check what is the best version
	 best=$(/usr/sbin/update-alternatives --query php-fpm | /usr/bin/awk '/Best/ {print $2}')
	
	 # if the best version not this version, use this version manual
	 if ! echo "${best}" | /usr/bin/grep -q "80"
	 then
    	 echo "php-fpm manual /usr/sbin/php8-fpm" | /usr/sbin/update-alternatives --set-selections >/dev/null 2>&1
	fi

  if /usr/sbin/service is-enabled php8-fpm.service
  then
      /usr/sbin/service daemon-reload
      /usr/sbin/service restart php8-fpm.service
  else
     /usr/sbin/service enable php8-fpm.service
     /usr/sbin/service start php8-fpm.service
  fi
	apache_start
else
    deactivate_modules
    /usr/sbin/service stop php8-fpm.service
    /usr/sbin/service disable php8-fpm.service
    apache_start
fi

exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------
