#!/bin/sh
#------------------------------------------------------------------------------
# /var/install/dialog.d/PHP8_EXT_MYSQL_PORT.sh - script dialog for ece
#
# Copyright (c) 2021 
# Last update:  $Id: PHP8FPM_EXT_MYSQL_PORT.sh 61718 2018-12-25 23:04:47Z schlotze $
#
# Copyright (c) 2017 the eisfair team, team(at)eisfair(dot)org
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

. /var/install/include/cuilib
. /var/install/include/ecelib

pgmname=`basename $0`
module_name="`echo "${pgmname}" | cut -d_ -f1 | tr '[:upper:]' '[:lower:]'`"

# debug mode true/false
#debug=true
if ${debug:-false}
then
    exec 2> /tmp/${module_name}-ext_mysql_port-dialog-trace$$.log
    set -x
    ask_debug=true
    export ask_debug
fi

#----------------------------------------------------------------------------
# exec_dailog
# ece --> request to create and execute dialog
#         $p2 --> main window handle
#         $p3 --> name of config variable
#----------------------------------------------------------------------------
exec_dialog()
{
    local win="$p2"
    local var_pref
    local var_prefix
    local separator
    local database_host
    local connect_port
    local my_server
    local my_port
    local p_list
    local sellist=''

    # get package-name and extract prefix
    var_pref=$(echo "${p3}" | sed 's/_PORT$//')

    ece_get_value ${win} ${var_pref}_HOST && database_host=${p2}

    if [ "${database_host}" = "localhost" ] ||
       [ "${database_host}" = "127.0.0.1" ]
    then
        my_server=$(find /etc/config.d  -maxdepth 1 \
                    -name 'mariadb' -printf '%f\n' -o \
                    -name 'mariadb[0-9]*' -printf '%f\n' -o \
                    -name 'mysql' -printf '%f\n' -o \
                    -name 'mysql[0-9]*' -printf '%f\n')

        separator=''
        for SERVER in ${my_server}
        do
            . /etc/config.d/${SERVER}

            var_prefix=$(echo ${SERVER} | tr [:lower:] [:upper:])

            eval connect_port='${'${var_prefix}'_CONNECT_PORT}'

            p_list="${connect_port}|${SERVER}"

            sellist="${sellist}${separator}${p_list}"
            separator=','
        done
    else
        my_port='3306 3307 3308 3309 3310 3311 3312 3313 3314 3315'

        # get extra portlist if exists
        if [ -f '/etc/mysql/portlist' ]
        then
            extra_port=$(cat /etc/mysql/portlist)
            my_port="${my_port} ${extra_port}"
        fi

        separator=''
        for PORT in ${my_port}
        do
            p_list="${PORT}|remote"

            sellist="${sellist}${separator}${p_list}"
            separator=','
        done
    fi

    ece_comment_list_dlg "$win" "Port used by" "$sellist"
}

#----------------------------------------------------------------------------
# main routine
#----------------------------------------------------------------------------

cui_init
cui_run

#----------------------------------------------------------------------------
# end
#----------------------------------------------------------------------------

exit 0

